@@ -91,7 +91,7 @@ pkts_in_func ( void )
                 last_bytes_out,
                 last_pkts_in,
                 last_pkts_out;
-   double bytes_in, bytes_out, pkts_in, pkts_out, t = 0;
+   double bytes_in=0, bytes_out=0, pkts_in=0, pkts_out=0, t = 0;
    unsigned long                diff;
    p = update_file(&proc_net_dev);
    if (proc_net_dev.last_read != stamp) {
@@ -111,7 +111,7 @@ pkts_in_func ( void )
           t = strtod( p, &p );
           pkts_in += t;
           for (i = 0; i < 6; i++) strtol(p, &p, 10);
-          t == strtod( p, &p );
+          t = strtod( p, &p );
           bytes_out += t;
          pkts_out += strtod( p, &p );
           }
@@ -151,7 +151,7 @@ pkts_out_func ( void )
                 last_bytes_out,
                 last_pkts_in,
                 last_pkts_out;
-   double bytes_in, bytes_out, pkts_in, pkts_out, t = 0;
+   double bytes_in=0, bytes_out=0, pkts_in=0, pkts_out=0, t = 0;
    unsigned long                diff;
    p = update_file(&proc_net_dev);
    if (proc_net_dev.last_read != stamp) {
@@ -171,7 +171,7 @@ pkts_out_func ( void )
           t = strtod( p, &p );
           pkts_in += t;
           for (i = 0; i < 6; i++) strtol(p, &p, 10);
-          t == strtod( p, &p );
+          t = strtod( p, &p );
           bytes_out += t;
          pkts_out += strtod( p, &p );
           }
@@ -210,7 +210,7 @@ bytes_out_func ( void )
                 last_bytes_out,
                 last_pkts_in,
                 last_pkts_out;
-   double bytes_in, bytes_out, pkts_in, pkts_out, t = 0;
+   double bytes_in=0, bytes_out=0, pkts_in=0, pkts_out=0, t = 0;
    unsigned long                diff;
    p = update_file(&proc_net_dev);
    if (proc_net_dev.last_read != stamp) {
@@ -230,7 +230,9 @@ bytes_out_func ( void )
           t = strtod( p, &p );
           pkts_in += t;
           for (i = 0; i < 6; i++) strtol(p, &p, 10);
-          t == strtod( p, &p );
+          /* Fixed 2003 by Dr Michael Wirtz <m.wirtz@tinnit.de>
+            and Phil Radden <P.Radden@rl.ac.uk> */
+          t = strtod( p, &p );
           bytes_out += t;
          pkts_out += strtod( p, &p );
           }
@@ -270,7 +272,7 @@ bytes_in_func ( void )
      last_bytes_out,
      last_pkts_in,
      last_pkts_out;
-   double bytes_in, bytes_out, pkts_in, pkts_out, t = 0;
+   double bytes_in=0, bytes_out=0, pkts_in=0, pkts_out=0, t = 0;
    unsigned long    diff;
    p = update_file(&proc_net_dev);
    if (proc_net_dev.last_read != stamp) {
@@ -292,7 +294,9 @@ bytes_in_func ( void )
           t = strtod( p, &p );
           pkts_in += t;
           for (i = 0; i < 6; i++) strtol(p, &p, 10);
-          t == strtod( p, &p );
+          /* Fixed 2003 by Dr Michael Wirtz <m.wirtz@tinnit.de>
+            and Phil Radden <P.Radden@rl.ac.uk>. */
+          t = strtod( p, &p );
           bytes_out += t;
           pkts_out += strtod( p, &p );
           }
@@ -929,9 +933,6 @@ float device_space(char *mount, char *device, double *total_size, double *total_
    uint32_t blocksize;
    uint32_t free;
    uint32_t size;
-   double reported_total, reported_free;
-   /* We report in GB = 1e9 bytes. */
-   double reported_units = 1e9;
    /* The percent used: used/total * 100 */
    float pct=0.0;
 
@@ -966,8 +967,7 @@ float find_disk_space(double *total_size, double *total_free)
    double reported_units = 1e9;
    /* Track the most full disk partition, report with a percentage. */
    float thispct, max=0.0;
-   int i, rc;
-   struct nlist *np, *next;
+   int rc;
 
    /* Read all currently mounted filesystems. */
    mounts=fopen(MOUNTS,"r");
